Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: third_party/WebKit/Source/platform/graphics/paint/RasterInvalidationTracking.h

Issue 2713673005: client-goodbye
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/paint/RasterInvalidationTracking.h
diff --git a/third_party/WebKit/Source/platform/graphics/paint/RasterInvalidationTracking.h b/third_party/WebKit/Source/platform/graphics/paint/RasterInvalidationTracking.h
index 33ac5b550da5aeb355cfbd3fc233ae74859b0a56..9ea77f76625bdd8f4c26fab74ae1cb0cc39a6ac0 100644
--- a/third_party/WebKit/Source/platform/graphics/paint/RasterInvalidationTracking.h
+++ b/third_party/WebKit/Source/platform/graphics/paint/RasterInvalidationTracking.h
@@ -16,13 +16,10 @@
namespace blink {
-class DisplayItemClient;
-
struct RasterInvalidationInfo {
DISALLOW_NEW_EXCEPT_PLACEMENT_NEW();
- // This is for comparison only. Don't dereference because the client may have
- // died.
- const DisplayItemClient* client;
+ // This is for comparison only. Don't dereference, the source may be gone.
+ const void* source;
String clientDebugName;
IntRect rect;
PaintInvalidationReason reason;

Powered by Google App Engine
This is Rietveld 408576698